
.. _pip: http://pip.openplans.org/
.. _PyPI: http://pypi.python.org/
.. _virtualenv: http://virtualenv.openplans.org/
.. _PyLint: http://www.logilab.org/857
.. _South: http://south.aeracode.org/
.. _diango-reversion: https://github.com/etianen/django-reversion

.. |concurrency| replace:: Concurrency
.. |pkg| replace:: dja
.. |version| replace:: 0.1

